Index: src/uri.js |
diff --git a/src/uri.js b/src/uri.js |
index c910d756b4c4cdc96336ba49cf0ea25bc3611fb6..72ca6f1565daa2d1b755e73622486afa4e1ddfc5 100644 |
--- a/src/uri.js |
+++ b/src/uri.js |
@@ -392,9 +392,8 @@ function URIUnescape(str) { |
// ------------------------------------------------------------------- |
-function SetUpUri() { |
- %CheckIsBootstrapping(); |
- // Set up non-enumerable URI functions on the global object and set |
+function SetupURI() { |
+ // Setup non-enumerable URI functions on the global object and set |
// their names. |
InstallFunctions(global, DONT_ENUM, $Array( |
"escape", URIEscape, |
@@ -406,4 +405,4 @@ function SetUpUri() { |
)); |
} |
-SetUpUri(); |
+SetupURI(); |